==> pyramid_sacrud-0.3.2.tar.gz: pyramid_sacrud-0.3.2/pyramid_sacrud/routes.py <==
#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2014 uralbash <root@uralbash.ru>
#
# Distributed under terms of the MIT license.

"""
Routes for pyramid_sacrud
"""

from . import CONFIG_RESOURCES, PYRAMID_SACRUD_HOME, PYRAMID_SACRUD_VIEW
from .common import pkg_prefix
from .resources import GroupResource
from pyramid.events import ApplicationCreated


def admin_factory(request):
    config = request.registry.settings[CONFIG_RESOURCES]
    return {
        str(group): GroupResource(group, resources)
        for group, resources in config
    }


def resources_preparing_factory(app, wrapper):
    """ Factory which wrap all resources in settings.
    """
    settings = app.app.registry.settings
    config = settings.get(CONFIG_RESOURCES, None)
    if not config:
        return

    resources = [(k, [wrapper(r, GroupResource(k, v)) for r in v])
                 for k, v in config]
    settings[CONFIG_RESOURCES] = resources


def resources_preparing(app):

    def wrapper(resource, parent):
        if not getattr(resource, '__parent__', False):
            resource.__parent__ = parent
        return resource

    resources_preparing_factory(app, wrapper)


def includeme(config):
    config.add_subscriber(resources_preparing, ApplicationCreated)
    prefix = pkg_prefix(config)
    config.add_route(PYRAMID_SACRUD_HOME, prefix)
    config.add_route(PYRAMID_SACRUD_VIEW, '/*traverse', factory=admin_factory)
    config.add_request_method(
        lambda x: prefix or config.route_prefix, 'sacrud_prefix',
        reify=True, property=True
    )

==> pyramid_sacrud-0.3.3.tar.gz: pyramid_sacrud-0.3.3/pyramid_sacrud/routes.py <==
#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2014 uralbash <root@uralbash.ru>
#
# Distributed under terms of the MIT license.

"""
Routes for pyramid_sacrud
"""

from . import CONFIG_RESOURCES, PYRAMID_SACRUD_HOME, PYRAMID_SACRUD_VIEW
from .resources import GroupResource
from pyramid.events import ApplicationCreated


def admin_factory(request):
    config = request.registry.settings[CONFIG_RESOURCES]
    return {
        str(group): GroupResource(group, resources)
        for group, resources in config
    }


def resources_preparing_factory(app, wrapper):
    """ Factory which wrap all resources in settings.
    """
    settings = app.app.registry.settings
    config = settings.get(CONFIG_RESOURCES, None)
    if not config:
        return

    resources = [(k, [wrapper(r, GroupResource(k, v)) for r in v])
                 for k, v in config]
    settings[CONFIG_RESOURCES] = resources


def resources_preparing(app):

    def wrapper(resource, parent):
        if not getattr(resource, '__parent__', False):
            resource.__parent__ = parent
        return resource

    resources_preparing_factory(app, wrapper)


def includeme(config):
    config.add_subscriber(resources_preparing, ApplicationCreated)
    if not config.route_prefix:
        config.route_prefix = 'sacrud'
    config.add_route(PYRAMID_SACRUD_HOME, '/')
    config.add_route(PYRAMID_SACRUD_VIEW, '/*traverse', factory=admin_factory)
    config.add_request_method(
        lambda x: config.route_prefix, 'sacrud_prefix',
        reify=True, property=True
    )
